@@ -1,5 +1,5 @@
 
-# $Id: makefile.h,v 1.579 2009-02-22 20:58:48 jhammond Exp $
+# $Id: makefile.h 21854 2012-01-25 01:30:25Z edo $
 #
 
 # Common definitions for all makefiles ... these can be overridden
@@ -19,19 +19,22 @@
 # For development tree 
 #RELEASE := 
 # For current release tree
-RELEASE := 6.0
+RELEASE := 6.1
 
 #
 
 ifndef NWCHEM_TOP
 error1:
-	@echo You must define NWCHEM_TOP in your environment to be the path
-	@echo of the top level nwchem directory ... something like
-	@echo     setenv NWCHEM_TOP /msrc/home/elvis/nwchem
-	@exit 1
+$(info     )
+$(info You must define NWCHEM_TOP in your environment to be the path)
+$(info of the top level nwchem directory ... something like)
+$(info     setenv NWCHEM_TOP /msrc/home/elvis/nwchem)
+$(info     )
+$(error )
 endif
 
-# Select the old (pre-1999 version of GA) by uncommenting the next line
+# Select the old (pre-autotools version of GA) by uncommenting the next line.
+# The value of OLD_GA does not matter -- it is detected as an ifdef only.
 #OLD_GA = y 
 
 #
@@ -70,30 +73,7 @@ ifeq (,$(RELEASE))
      CODE_BRANCH := Development
 else
 ifeq (,$(findstring $(RELEASE),$(NWCHEM_TOP)))
-error3:
-	@echo
-	@echo
-	@echo === ERROR: invalid directory name $(NWCHEM_TOP) ===
-	@echo
-	@echo NWChem insists that the release number is part of the
-	@echo top level directory name. It does not matter where
-	@echo the release number appears but it has to be present.
-	@echo
-	@echo Examples of valid top level directory names are:
-	@echo
-	@echo "   - $(NWCHEM_TOP)-$(RELEASE)"
-	@echo "   - $(RELEASE)-nwchem-build"
-	@echo "   - nwchem-$(RELEASE)-again"
-	@echo "   - nwchem$(RELEASE)"
-	@echo "   - aaa$(RELEASE)zzz"
-	@echo
-	@echo Please move the source code directoy to one that
-	@echo matches this naming requirement.
-	@echo
-	@echo === ERROR: invalid directory name $(NWCHEM_TOP) ===
-	@echo
-	@echo
-	@exit 3
+     TOPDIR := $(NWCHEM_TOP)-$(RELEASE)
 else
      TOPDIR := $(NWCHEM_TOP)
 endif
@@ -121,7 +101,11 @@ endif
 # e.g. LIBPATH = -L/msrc/proj/mss/lib
 #
     LIBPATH = 
+ifdef OLD_GA
     LIBPATH = -L$(SRCDIR)/tools/lib/$(TARGET)
+else
+    LIBPATH = -L$(SRCDIR)/tools/install/lib
+endif
 
 #
 # Define INCPATH to be directories to get includes for
@@ -129,7 +113,11 @@ endif
 # will be searched AFTER anything you are building now.
 #
     INCPATH = 
+ifdef OLD_GA
     INCPATH = -I$(SRCDIR)/tools/include
+else
+    INCPATH = -I$(SRCDIR)/tools/install/include
+endif
 
 # These subdirectories will build the core, or supporting libraries
 # that are required by all NWChem modules.  The include directory is
@@ -255,7 +243,11 @@ BUILDING_PYTHON = $(filter $(NWSUBDIRS),python)
           CDEBUG = -g
               AR = ar
 
-       CORE_LIBS =  -lnwcutil -lpario -lglobal -lma -lpeigs -lperfm -lcons -lbq -lnwcutil
+ifdef OLD_GA
+       CORE_LIBS = -lnwcutil -lpario -lglobal -lma -lpeigs -lperfm -lcons -lbq -lnwcutil
+else
+       CORE_LIBS = -lnwcutil -lga -lpeigs -lperfm -lcons -lbq -lnwcutil
+endif
 
     ifdef USE_INTEGER4
       integer4:
@@ -1110,27 +1102,13 @@ ifeq ($(TARGET),MACX)
 #
 # MacOSX 
 #
-# 
-#  ifndef USE_MPI
-#  mpimacx:
-#	@echo You must define USE_MPI=y to compile
-#	@echo nwchem on MAC OS X.
-#	@echo Please type
-#	@echo 
-#	@echo " make  USE_MPI=y"
-#	@echo "  or "
-#	@echo " make  FC=xlf USE_MPI=y"
-#	@echo 
-#	@exit 1
-#  endif
-#
 ifdef USE_VECLIB
     CORE_SUBDIRS_EXTRA =  blas
 else
     CORE_SUBDIRS_EXTRA =  blas lapack
 endif
                _CPU = $(shell machine  )
-
+                    FC = gfortran
                INSTALL = @echo nwchem is built
                RANLIB = ranlib
              MAKEFLAGS = -j 1 --no-print-directory
@@ -1179,7 +1157,12 @@ endif
         LINK.f = gfortran  $(LDFLAGS) 
         FOPTIONS   = -Wextra #-Wunused #-ffast-math
         FOPTIMIZE  = -O2 -ffast-math -Wuninitialized 
-       DEFINES  += -DGFORTRAN
+        DEFINES  += -DGFORTRAN
+        ifdef USE_OPENMP
+           FOPTIONS  += -fopenmp
+           LDOPTIONS += -fopenmp
+           DEFINES += -DUSE_OPENMP
+        endif
         ifeq ($(_CPU),ppc970)
 #G5
          FVECTORIZE = -ffast-math  -O2 -ftree-vectorize 
@@ -1260,36 +1243,17 @@ ifeq ($(TARGET),MACX64)
   FC = gfortran
   _FC = gfortran
 #
-# MacOSX 
-#
-# 
-  ifndef USE_MPI
-  mpimacx64:
-	@echo You must define USE_MPI=y to compile
-	@echo nwchem on 64bit MAC OS X.
-	@echo Please type
-	@echo 
-	@echo " make  USE_MPI=y"
-	@echo "  or "
-	@echo " make  FC=gfortran USE_MPI=y"
-	@echo 
-	@exit 1
-  endif
-  ifndef USE_64TO32
-  macx64to32:
-	@echo You must define USE_64TO32=y to compile
-	@echo nwchem on 64bit MAC OS X.
-	@echo Please type
-	@echo 
-	@echo " make  USE_64TO32=y"
-	@echo "  or "
-	@echo " make  FC=gfortran USE_64TO32=y"
-	@echo 
-	@exit 1
-  endif
+# MacOSX 64bit
 #
 ifdef USE_VECLIB
-    CORE_SUBDIRS_EXTRA =  blas
+ifdef USE_64TO32
+   CORE_SUBDIRS_EXTRA =
+else
+vecliberr:
+	@echo The Apple supplied vector math library does not support 8-byte integers
+	@echo You must also set USE_64TO32 and do a "make 64_to_32" to change the source code
+	@exit 1
+endif
 else
     CORE_SUBDIRS_EXTRA =  blas lapack
 endif
@@ -1311,8 +1275,7 @@ endif
        DEFINES  += -DEXT_INT
 #
          FOPTIMIZE+= -funroll-all-loops -mtune=native 
-#         FVECTORIZE=-O3 -ffast-math -mtune=native -mfpmath=sse -msse3# -ftree-vectorize -ftree-vectorizer-verbose=1   -fprefetch-loop-arrays  -funroll-all-loops 
-#         FVECTORIZE=-O3 -ffast-math -mtune=native -mfpmath=sse -msse3 -ftree-vectorize -ftree-vectorizer-verbose=1   -fprefetch-loop-arrays  -funroll-all-loops 
+         FVECTORIZE=-O3 -ffast-math -mtune=native -mfpmath=sse -msse3 -ftree-vectorize -ftree-vectorizer-verbose=1   -fprefetch-loop-arrays  -funroll-all-loops 
 #         FOPTIMIZE=-O1
 #         FVECTORIZE=-O1
        endif
@@ -1332,12 +1295,7 @@ endif
     else
       EXTRA_LIBS += -lm -lcc_dynamic
     endif
-  endif
 #
-   _V104=$(shell uname -v 2>&1|awk ' /Version 7./ {print "N";exit}; /Version 8./ {print "Y";exit}')
-  ifeq ($(_V104),Y)
-    EXTRA_LIBS +=-lSystemStubs
-
 
 endif
 
@@ -1776,9 +1734,6 @@ endif
       ifeq ($(CC),pgcc)
         _CC=pgcc
       endif
-      ifeq ($(FC),pathf90)
-        _FC=pathf90
-      endif
       ifeq ($(FC),pgf90)
         _FC=pgf90
       endif
@@ -1834,9 +1789,7 @@ endif
           FOPTIMIZE += -xW
         endif
       endif	
-      
-#      USE_LIB64 = y #for python linking
-
+#      
       ifeq ($(_FC),pgf90)
         FOPTIONS   += -Mdalign -Mllalign -Kieee 
 #        FOPTIONS   += -tp k8-64  
@@ -1846,14 +1799,14 @@ endif
         FDEBUG = -g -O2
         DEFINES  += -DCHKUNDFLW -DPGLINUX
        ifeq ($(FC),ftn)
-          DEFINES  += -DCRAYXT
+          DEFINES  += -DCRAYXT -DEAFHACK -DNOFSCHECK
           LINK.f = ftn  $(LDFLAGS) $(FOPTIONS)
        endif
        ifeq ($(NWCHEM_TARGET),CATAMOUNT)
           LINK.f = ftn  $(LDFLAGS) $(FOPTIONS)
        endif
       endif
-      ifeq ($(_FC),pathf90)
+      ifeq ($(FC),pathf90)
 #pathscale 1.3 compiler
 # tested Sep 30 2004 on RH AW3
         FOPTIONS   += -cpp -Wp,-P
@@ -1869,8 +1822,7 @@ endif
       ifeq ($(_CC),pgcc)
         COPTIONS   =   -O
       else
-        # NEED TO COMMENT OUT GNU OPTIONS SINCE THIS IS THE "ELSE" FOR COPTIONS
-        COPTIONS   =   -O3 #-funroll-loops -ffast-math  
+        COPTIONS   =   -O3 -funroll-loops -ffast-math  
       endif
       ifdef USE_GCC34
         COPTIONS  +=   -march=k8 -mtune=k8
@@ -2011,9 +1963,15 @@ ifeq ($(TARGET),FUJITSU_VPP)
  NW_CORE_SUBDIRS = include basis geom inp input  \
        pstat rtdb task symmetry util peigs $(CORE_SUBDIRS_EXTRA)
 
+ifdef OLD_GA
         CORE_LIBS = -lnwcutil \
                     -L$(GA_LIBDIR) -lglobal -lpario -lma -lpeigs \
                     -ltcgmsg-mpi -L/usr/lang/mpi2/lib32 -lmpi -lmp
+else
+        CORE_LIBS = -lnwcutil \
+                    -L$(GA_LIBDIR) -lga -lpeigs \
+                    -L/usr/lang/mpi2/lib32 -lmpi -lmp
+endif
        EXTRA_LIBS = -llapackvp -lblasvp -lsocket -Wl,-J,-P,-t,-dy
 #end of FUJITSU_VPP 
 endif
@@ -2060,9 +2018,15 @@ ifeq ($(TARGET),FUJITSU_VPP64)
  NW_CORE_SUBDIRS = include basis geom inp input  \
        pstat rtdb task symmetry util peigs $(CORE_SUBDIRS_EXTRA)
 
+ifdef OLD_GA
         CORE_LIBS = -lnwcutil \
                     -L$(GA_LIBDIR) -lglobal -lpeigs -lpario -lma \
                     -ltcgmsg-mpi -L/usr/lang/mpi2/lib64 -lmpi -lmp
+else
+        CORE_LIBS = -lnwcutil \
+                    -L$(GA_LIBDIR) -lga -lpeigs \
+                    -L/usr/lang/mpi2/lib64 -lmpi -lmp
+endif
        EXTRA_LIBS = -llapack -lblas -lsocket -Wl,-J,-P,-t,-dy
 #end of FUJITSU_VPP64
 endif
@@ -2108,41 +2072,35 @@ ifeq ($(TARGET),$(findstring $(TARGET),BGL BGP))
    FCONVERT = $(CPP) $(CPPFLAGS) $< > $*.f
    LDOPTIONS =  -Wl,--relax
 
-   DEFINES = -DLINUX
-   FDEBUG  = -g
-   COPTIMIZE = -g
-   FOPTIMIZE = -g
-   FOPTIONS = -g
+   DEFINES = -DLINUX -DXLFLINUX
+   FDEBUG  = -g -O2
+   COPTIMIZE = -g -O3 -qstrict
+   FOPTIMIZE = -g -O3 -qnoipa -qfloat=rsqrt:fltint
+   FOPTIONS = -qEXTNAME -qxlf77=leadzero -NQ40000 -NT80000 -NS2048 -qmaxmem=8192
 
 #for BGL
+#   ifeq ($(FC),blrts_xlf)
    ifeq ($(TARGET),BGL)
-    DEFINES  += -DBGML -DBGL
-   endif
-
-   ifeq ($(FC),blrts_xlf)
     CC     = $(BGCOMPILERS)/powerpc-bgl-blrts-gnu-gcc
     AR     = $(BGCOMPILERS)/powerpc-bgl-blrts-gnu-ar
     AS     = $(BGCOMPILERS)/powerpc-bgl-blrts-gnu-as
     RANLIB = $(BGCOMPILERS)/powerpc-bgl-blrts-gnu-ranlib
-    DEFINES += -DXLFLINUX -DBGL
-    FOPTIMIZE += -qarch=440 -qtune=440 -qfloat=rsqrt:fltint
-    FOPTIONS = -qEXTNAME -qxlf77=leadzero -NQ40000 -NT80000 -NS2048 -qmaxmem=8192
+    DEFINES += -DBGL
+    FOPTIMIZE += -qarch=440 -qtune=440
    endif
 
 #for BGP
+#   ifeq ($(FC),$(findstring $(FC),bgxlf bgxlf_r))
    ifeq ($(TARGET),BGP)
-    DEFINES += -DDCMF -DBGP
-   endif
-
-   ifeq ($(FC),$(findstring $(FC),bgxlf bgxlf_r mpixlf77 mpixlf77_r))
     CC     = $(BGCOMPILERS)/powerpc-bgp-linux-gcc
     AR     = $(BGCOMPILERS)/powerpc-bgp-linux-ar
     AS     = $(BGCOMPILERS)/powerpc-bgp-linux-as
     RANLIB = $(BGCOMPILERS)/powerpc-bgp-linux-ranlib
-    DEFINES += -DXLFLINUX
-    FOPTIONS = -qEXTNAME -qxlf77=leadzero -NQ40000 -NT80000 -NS2048 -qmaxmem=8192
-    FOPTIONS += -O3 -qstrict -qthreaded -qnosave -qalign=4k
-    FOPTIMIZE += -O3 -qarch=450d -qtune=450 -qcache=auto -qunroll=auto -qfloat=rsqrt:fltint
+    DEFINES  += -DDCMF -DBGP -DNOFSCHECK
+    FOPTIONS += -qthreaded -qnosave -qalign=4k
+    FOPTIMIZE += -qarch=450d -qtune=450
+    COPTIMIZE += -qarch=450 -qtune=450
+
     XLF11 = $(shell bgxlf -qversion  2>&1|grep Version|head -1| awk ' / 11./ {print "Y"}')
    endif
 
@@ -2172,14 +2130,14 @@ errorpython2:
 	@echo " subdirs <$(NWSUBDIRS)>"
 	@exit 1
 endif
-###### !!!! Turning this off since lib64 doesnot seem like a standard!!!! ######
+#
 ifdef USE_PYTHON64
- CORE_LIBS += $(PYTHONHOME)/lib64/python$(PYTHONVERSION)/config/libpython$(PYTHONVERSION).a
+  CORE_LIBS += $(PYTHONHOME)/lib64/python$(PYTHONVERSION)/config/libpython$(PYTHONVERSION).a
 else
- CORE_LIBS += $(PYTHONHOME)/lib/python$(PYTHONVERSION)/config/libpython$(PYTHONVERSION).a
+  CORE_LIBS += $(PYTHONHOME)/lib/python$(PYTHONVERSION)/config/libpython$(PYTHONVERSION).a
 endif
-
 endif
+#
 ######
 #PAPI#
 ######
@@ -2247,12 +2205,12 @@ endif
   CORE_LIBS += $(SCALAPACK) $(PBLAS) $(BLACS)
 endif
 
-ifdef BLASOPT
-       CORE_LIBS +=  $(BLASOPT) 
-endif
 ifdef USE_64TO32
       CORE_LIBS +=  -l64to32
 NWSUBDIRS += 64to32blas
+endif
+ifdef BLASOPT
+       CORE_LIBS +=  $(BLASOPT) 
 endif
       CORE_LIBS +=  -llapack  -lblas 
 
@@ -2268,7 +2226,11 @@ endif
 #  some of the definitions below will be 'lost'                   #
 ###################################################################
 #the new GA uses ARMCI library
+ifdef OLD_GA
       CORE_LIBS += -larmci
+else
+      CORE_LIBS +=
+endif
 
 # MPI version requires tcgmsg-mpi library
 
@@ -2276,12 +2238,24 @@ ifdef USE_MPI
 ifndef LIBMPI 
   LIBMPI = -lmpi 
 endif 
+SKIP_LIBMPI = mpifrt mpfort mpif77 mpxlf mpif90 ftn
+ifneq (,$(findstring $(notdir $(FC)), $(SKIP_LIBMPI)))
+  LIBMPI =
+endif
 ifdef MPI_LIB 
-      CORE_LIBS += -L$(MPI_LIB) 
+      CORE_LIBS += $(patsubst -L-L%,-L%,-L$(MPI_LIB))
 endif 
+ifdef OLD_GA
   CORE_LIBS += -ltcgmsg-mpi $(LIBMPI) 
+else
+  CORE_LIBS += $(LIBMPI) 
+endif
 else 
+ifdef OLD_GA
   CORE_LIBS += -ltcgmsg 
+else
+  CORE_LIBS += 
+endif
 endif 
 
 
