@@ -1,5 +1,5 @@
 /*
- $Id: util_file_unlink.c,v 1.6 2003-08-13 18:06:11 edo Exp $
+ $Id: util_file_unlink.c 20277 2011-05-05 16:59:07Z d3p852 $
  */
 
 /*
@@ -21,6 +21,7 @@
 #define FATR
 #endif
 #include "eaf.h"
+#include "ga.h"
 
 #if defined(USE_FCD)
 int fortchar_to_string(_fcd, int, char *, const int);
@@ -28,8 +29,6 @@ int fortchar_to_string(_fcd, int, char *, const int);
 int fortchar_to_string(const char *, int, char *, const int);
 #endif
 
-void ga_error(const char *, long);
-
 void util_file_unlink(const char *filename)
 /*
   Delete the file.  If the file does not exist, quietly return.
@@ -41,12 +40,12 @@ void util_file_unlink(const char *filename)
 	if (unlink(filename)) {
 	    fprintf(stderr,"util_file_unlink: failed unlinking %s\n",
 		    filename);
-	    ga_error("util_file_unlink",0);
+	    GA_Error("util_file_unlink",0);
 	}
     }
   */
-  if (eaf_delete(filename) != 0)
-    ga_error("util_file_unlink",0);
+  if (EAF_Delete(filename) != 0)
+    GA_Error("util_file_unlink",0);
 }
 
 #if defined(USE_FCD)
@@ -59,7 +58,7 @@ void util_file_unlink_(const char *input, int lin)
 #endif
     char in[255];
     if (!fortchar_to_string(input, lin, in, sizeof(in)))
-	ga_error("util_file_unlink: fortchar_to_string failed for in",0);
+	GA_Error("util_file_unlink: fortchar_to_string failed for in",0);
     util_file_unlink(in);
 }
 
